@@ -5,27 +5,27 @@ from __future__ import absolute_import, unicode_literals
 
 import contextlib
 import enum
-from typing import List, Tuple
+from typing import Dict, List, Tuple
 
 from hutils.shortcuts import list_get
 
 
 class EmptyContextManager(contextlib.ContextDecorator):
-    """ empty context manager. """
+    """empty context manager."""
 
     def __init__(self):
-        """ do nothing """
+        """do nothing"""
 
     def __enter__(self):
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
-        """ Always throw exception """
+        """Always throw exception"""
         return False
 
 
 class TupleEnum(enum.Enum):
-    """ 元组枚举类，可以用来存储多层信息。tuple enum for multi-dimension data enum.
+    """元组枚举类，可以用来存储多层信息。tuple enum for multi-dimension data enum.
 
     Examples::
 
@@ -56,13 +56,17 @@ class TupleEnum(enum.Enum):
 
     @property
     def lower_name(self):
-        """ name in lower case """
+        """name in lower case"""
         return self.name.lower()
 
     @classmethod
     def chinese_choices(cls) -> List[Tuple]:
         return [(_.value, _.chinese) for _ in cls]
 
+    @classmethod
+    def chinese_items(cls) -> Dict:
+        return dict(cls.chinese_choices())
+
     @classmethod
     def values(cls) -> Tuple:
         return tuple(_.value for _ in cls)
